/***************************************************************************
 *   Copyright 2006-2007 Alexander Dymo  <adymo@kdevelop.org>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#include "mainwindowoperator.h"

#include "mainwindow.h"

namespace Sublime {

void MainWindowOperator::setArea(MainWindow *w, Area *area)
{
    w->setArea(area);
}

void MainWindowOperator::clearArea(MainWindow *w)
{
    w->clearArea();
}

void MainWindowOperator::setActiveView(MainWindow *w, View *view)
{
    w->activateView(view);
}

void MainWindowOperator::setActiveToolView(MainWindow *w, View *view)
{
    w->setActiveToolView(view);
}

}
